@@ -123,17 +123,4 @@ public abstract class AbstractGroupAction implements AJAXActionService {
     protected static AJAXRequestResult getJSONNullResult() {
         return RESULT_JSON_NULL;
     }
-
-    protected static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
 }
